==> estateplat-common-1.2.4-20190213.091222-103-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsYwr.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2018/10/22
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
*@Description:卖方核税表
*@Date 13:19 2018/10/22
*/
@Entity
@Table( name ="YCSL_HS_YWR" )
public class YcslHsYwr implements Serializable {
    /**
     * 核税ID
     */
    @Column(name = "HSID" )
    @Id
    private String hsid;
    /**
     * 项目id
     */
    @Column(name = "PROID" )
    private String proid;
    /**
     * 核定计税价格
     */
    @Column(name = "HSDJJG" )
    private Double hsdjjg;
    /**
     * 应征税额合计
     */
    @Column(name = "YZSEHJ" )
    private Double yzsehj;
    /**
     * 减免税额合计
     */
    @Column(name = "JMSEHJ" )
    private Double jmsehj;
    /**
     * 实际应征合计
     */
    @Column(name = "SJYZHJ" )
    private Double sjyzhj;


    public String getHsid() {
        return hsid;
    }

    public void setHsid(String hsid) {
        this.hsid = hsid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getHsdjjg() {
        return hsdjjg;
    }

    public void setHsdjjg(Double hsdjjg) {
        this.hsdjjg = hsdjjg;
    }

    public Double getYzsehj() {
        return yzsehj;
    }

    public void setYzsehj(Double yzsehj) {
        this.yzsehj = yzsehj;
    }

    public Double getJmsehj() {
        return jmsehj;
    }

    public void setJmsehj(Double jmsehj) {
        this.jmsehj = jmsehj;
    }

    public Double getSjyzhj() {
        return sjyzhj;
    }

    public void setSjyzhj(Double sjyzhj) {
        this.sjyzhj = sjyzhj;
    }
}

==> estateplat-common-1.2.4-20190813.051309-212-sources.jar: cn/gtmap/estateplat/model/acceptance/YcslHsYwr.java <==
package cn.gtmap.estateplat.model.acceptance;/*
 * @author <a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
 * @version 1.0, 2018/10/22
 * @description 
 */

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
*@Author:<a href="mailto:huangzijian@gtmap.cn">huangzijian</a>
*@Description:卖方核税表
*@Date 13:19 2018/10/22
*/
@Entity
@Table( name ="YCSL_HS_YWR" )
public class YcslHsYwr implements Serializable {
    /**
     * 核税ID
     */
    @Column(name = "HSID" )
    @Id
    private String hsid;
    /**
     * 项目id
     */
    @Column(name = "PROID" )
    private String proid;
    /**
     * 核定计税价格
     */
    @Column(name = "HSDJJG" )
    private Double hsdjjg;
    /**
     * 应征税额合计
     */
    @Column(name = "YZSEHJ" )
    private Double yzsehj;
    /**
     * 减免税额合计
     */
    @Column(name = "JMSEHJ" )
    private Double jmsehj;
    /**
     * 实际应征合计
     */
    @Column(name = "SJYZHJ" )
    private Double sjyzhj;
    /**
     * 完税状态 1 完税  0 未完税
     */
    @Column(name = "WSZT" )
    private String wszt;

    public String getHsid() {
        return hsid;
    }

    public void setHsid(String hsid) {
        this.hsid = hsid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getHsdjjg() {
        return hsdjjg;
    }

    public void setHsdjjg(Double hsdjjg) {
        this.hsdjjg = hsdjjg;
    }

    public Double getYzsehj() {
        return yzsehj;
    }

    public void setYzsehj(Double yzsehj) {
        this.yzsehj = yzsehj;
    }

    public Double getJmsehj() {
        return jmsehj;
    }

    public void setJmsehj(Double jmsehj) {
        this.jmsehj = jmsehj;
    }

    public Double getSjyzhj() {
        return sjyzhj;
    }

    public void setSjyzhj(Double sjyzhj) {
        this.sjyzhj = sjyzhj;
    }

    public String getWszt() {
        return wszt;
    }

    public void setWszt(String wszt) {
        this.wszt = wszt;
    }
}
